@@ -8,7 +8,7 @@ use Error::Pure qw(err);
 use File::Spec::Functions qw(catdir catfile splitdir);
 use FindBin qw($Bin $Script);
 
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 # Constructor.
 sub new {
@@ -383,6 +383,8 @@ Returns instance of object.
 
 =head1 EXAMPLE1
 
+=for comment filename=actual_directory.pl
+
  use strict;
  use warnings;
 
@@ -396,6 +398,8 @@ Returns instance of object.
 
 =head1 EXAMPLE2
 
+=for comment filename=parent_directory.pl
+
  use strict;
  use warnings;
 
@@ -409,6 +413,8 @@ Returns instance of object.
 
 =head1 EXAMPLE3
 
+=for comment filename=relative_file_path_to_defined_dir.pl
+
  use strict;
  use warnings;
 
@@ -435,6 +441,8 @@ Returns instance of object.
 
 =head1 EXAMPLE4
 
+=for comment filename=relative_dir_path_to_defined_dir.pl
+
  use strict;
  use warnings;
 
@@ -492,12 +500,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2009-2022
+© 2009-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.15
+0.16
 
 =cut
